@@ -42,7 +42,7 @@ launch_json = {
     ],
 }
 
-main_py = """\n
+main_py = """
 import sys
 def ipc_main():
     globals()[sys.argv[1]]()
@@ -54,7 +54,7 @@ ipc_main()
 def build_py(functions):
     pre = "# Built using vscode-ext\n\n"
     with open(inspect.getfile(functions[0]), "r") as f:
-        imports = pre + "".join([l for l in f.readlines() if not ".build(" in l])
+        imports = pre + "".join([l for l in f.readlines() if not "build(" in l])
     imports += "\n"
     main = main_py
     code = imports + main
@@ -86,6 +86,9 @@ def build_js(name, events, commands):
 py.stdout.on("data", (data) => {
     executeCommands(py, data);
 });
+py.stderr.on("data", (data) => {
+    console.error(`An Error occurred in the python script: ${data}`);
+});
 """
         code_on_activate += "});\n"
         code_on_activate += f"context.subscriptions.push({command.name});\n"
@@ -186,7 +189,7 @@ def build(extension, publish=False, config=None):
                 }
             ]
         }
-        if package_config["contributes"].has_key("views"):
+        if "views" in package_config["contributes"]:
             package_config["contributes"]["views"].update(view)
         else:
             package_config["contributes"]["views"] = view
